==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/it/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confermi elementi di eliminazione di massa',
  'bulk_delete_help'	=> 'Rivedi gli assets sottostanti per la cancellazione massiva. Una volta cancellati, questi assets potranno essere ripristinati, ma non saranno più associati ad alcun utente cui siano attualmente assegnati.',
  'bulk_delete_warn'	=> 'Stai per cancellare :asset_count assets.',
	'bulk_update'		=> 'Aggiornamento quantità beni',
	'bulk_update_help'	=> 'Questo modulo consente di aggiornare più risorse in una sola volta. Riempire solo i campi che è necessario cambiare. Tutti i campi lasciati vuoti rimarranno invariati. ',
	'bulk_update_warn'	=> 'Stai per modificare le proprietà di :asset_count beni.',
    'checkedout_to'		=> 'Assegnato a',
    'checkout_date'		=> 'Data di assegnazione',
    'checkin_date'		=> 'Data di entrata',
    'checkout_to'		=> 'Assegnare a',
    'cost'				=> 'Costo acquisto',
    'create'			=> 'Creare bene',
    'date'				=> 'Data di acquisto',
    'depreciation'	    => 'Ammortamento',
    'depreciates_on'	=> 'Deprezza Si',
    'default_location'	=> 'Posizione predefinita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Tasso EOL',
    'expected_checkin'  => 'Richiesta Data di entrata',
    'expires'			=> 'Scade',
    'fully_depreciated'	=> 'Completamente ammortizzato',
    'help_checkout'		=> 'Se vuoi assegnare questo prodotto immediatamente, seleziona "Pronto alla spedizione" dalla barra di stato qui sopra. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Produttore',
    'model'				=> 'Modello',
    'months'			=> 'mesi',
    'name'				=> 'Nome bene',
    'notes'				=> 'Note',
    'order'				=> 'Numero Ordine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Gli utenti possono richiedere questo bene',
    'select_statustype'	=> 'Selezionare il tipo di stato',
    'serial'			=> 'Seriale',
    'status'			=> 'Stato',
    'tag'				=> 'Etichetta bene',
    'update'			=> 'Aggiornamento bene',
    'warranty'			=> 'Garanzia',
		'warranty_expires'		=> 'Scadenza della garanzia',
    'years'				=> 'anni',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/it/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confermi elementi di eliminazione di massa',
  'bulk_delete_help'	=> 'Rivedi gli assets sottostanti per la cancellazione massiva. Una volta cancellati, questi assets potranno essere ripristinati, ma non saranno più associati ad alcun utente cui siano attualmente assegnati.',
  'bulk_delete_warn'	=> 'Stai per cancellare :asset_count assets.',
    'bulk_update'		=> 'Aggiornamento quantità beni',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più risorse in una sola volta. Riempire solo i campi che è necessario cambiare. Tutti i campi lasciati vuoti rimarranno invariati. ',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di :asset_count beni.',
    'checkedout_to'		=> 'Assegnato a',
    'checkout_date'		=> 'Data del check-out',
    'checkin_date'		=> 'Data di entrata',
    'checkout_to'		=> 'Assegnare a',
    'cost'				=> 'Costo acquisto',
    'create'			=> 'Creare bene',
    'date'				=> 'Data di acquisto',
    'depreciation'	    => 'Ammortamento',
    'depreciates_on'	=> 'Deprezza Si',
    'default_location'	=> 'Posizione predefinita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Tasso EOL',
    'expected_checkin'  => 'Richiesta Data di entrata',
    'expires'			=> 'Scade',
    'fully_depreciated'	=> 'Completamente ammortizzato',
    'help_checkout'		=> 'Se vuoi assegnare questo prodotto immediatamente, seleziona "Pronto alla spedizione" dalla barra di stato qui sopra. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Produttore',
    'model'				=> 'Modello',
    'months'			=> 'mesi',
    'name'				=> 'Nome bene',
    'notes'				=> 'Note',
    'order'				=> 'Numero Ordine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Gli utenti possono richiedere questo bene',
    'select_statustype'	=> 'Selezionare il tipo di stato',
    'serial'			=> 'Seriale',
    'status'			=> 'Stato',
    'tag'				=> 'Etichetta bene',
    'update'			=> 'Aggiornamento bene',
    'warranty'			=> 'Garanzia',
        'warranty_expires'		=> 'Scadenza della garanzia',
    'years'				=> 'anni',
    'asset_location' => 'Aggiorna Posizione Bene',
    'asset_location_update_default_current' => 'Aggiorna sia la posizione predefinita che quella attuale',
    'asset_location_update_default' => 'Aggiorna solo la posizione predefinita',
    'asset_not_deployable' => 'Lo stato del bene è "Non Assegnabile". Non puoi fare il check-out di questo bene.',
    'asset_deployable' => 'Lo stato del bene è "Assegnabile". Puoi fare il check-out di questo bene.',
    'processing_spinner' => 'Elaborazione...',
];
